@@ -1,7 +1,9 @@
 package Neo4j::Bolt::NeoValue;
+use v5.12;
+use warnings;
 
 BEGIN {
-  our $VERSION = "0.5000";
+  our $VERSION = "0.5001";
   require Neo4j::Bolt::CTypeHandlers;
   require Neo4j::Bolt::CResultStream;
   require XSLoader;
