@@ -1,8 +1,9 @@
 package Neo4j::Bolt::ResultStream;
-# use Neo4j::Client;
+use v5.12;
+use warnings;
 
 BEGIN {
-  our $VERSION = "0.5000";
+  our $VERSION = "0.5001";
   require Neo4j::Bolt::Cxn;
   require Neo4j::Bolt::CResultStream;
   require XSLoader;
